@@ -15,7 +15,7 @@ pub use crate::msg::Cw721ExecuteMsg;
 pub use crate::query::{
     AllNftInfoResponse, Approval, ApprovedForAllResponse, ApprovalResponse, ApprovalsResponse, ContractInfoResponse,
     Cw721QueryMsg, NftInfoResponse, NumTokensResponse, OperatorsResponse, OwnerOfResponse,
-    TokensResponse,
+    TokensResponse, BalanceOfResponse
 };
 pub use crate::receiver::Cw721ReceiveMsg;
 pub use crate::traits::{CustomMsg, Cw721, Cw721Execute, Cw721Query};
